#! /usr/bin/env python

# This program reads
# 1) a file of target scores
# 2) a file of null scores
#
# It calculate a qvalue for each target score
# based on the list of null scores
# 
# By default, the smaller the score, the higher rank

import sys

usage = "USAGE: compute_qv_nullScores <targetFile> <nullFile> \n"


def count_falsePositives(currSc, nullNum, nullList, nullIx):

    # notice that nullIx is negative
    # i.e. counting from the end
    while (nullIx >= -nullNum) and \
          (nullList[nullIx] > currSc):
        nullIx -= 1
        
    # the number of false positives in the null list
    # i.e. the number of scores <= currSc
    res = nullNum + nullIx + 1

    return (res, nullIx)


if __name__ == '__main__':

    if (len(sys.argv) < 2):
        sys.stderr.write(usage)
        sys.exit(1)

    targetFile = sys.argv[1]
    nullFile = sys.argv[2]


    tgtList = []
    fpTarget = open(targetFile, 'r')
    for line in fpTarget:
        tgtList.append(float(line[:-1]))
    fpTarget.close()

    # sort the target list
    tgtList.sort()

    nullList = []    
    fpNull = open(nullFile, 'r')
    for line in fpNull:
        nullList.append(float(line[:-1]))
    fpNull.close()

    # sort the null list
    nullList.sort()


    numTgt = len(tgtList)
    numNull = len(nullList)
    # constant, accounting for different length 
    # of the target list and the null list 
    f = float(numTgt) / numNull

    currSc = tgtList[-1]
    nullIx = -1
    # count number of FPs in the null scores
    (falsePos, nullIx) = \
        count_falsePositives(currSc, numNull, nullList, nullIx)

    qv = (f * falsePos) / numTgt
    qvList = [qv]
    
    lastQv = qv
    lastSc = currSc

    for i in xrange(-2, -(numTgt+1), -1):
        currSc = tgtList[i]

        if currSc == lastSc:
            qv = lastQv
        else:
            # count number of FPs in the null scores
            (falsePos, nullIx) = \
                count_falsePositives(currSc, numNull, nullList, nullIx)
            # Notice i is negative
            # (numTgt+i+1) is the rank of currSc 
            fdr = (f * falsePos) / (numTgt + i + 1)
            qv = min(fdr, lastQv)
            
            lastQv = qv 
            lastSc = currSc
            
        qvList.insert(0, qv)


    # output
    for i in xrange(0, numTgt):
        sys.stdout.write(str(tgtList[i]) + '\t' +
                         str(qvList[i]) + '\n')
