#! /usr/bin/env python

# This program reads
# 1) the .gff file generated by Fimo.
#   (the results of scanning macisaac sites using macisaac PWMs)
# 2) pvalue threshold or qvalue threshold for the interesting hits 
# 3) the bed file of macisaac sites

# It identifies the matched macissac sites. 
# i.e. If a site of TF A gets a hit of TF A's PWM with significant pv or qv, this site is called a "matched" site.

# It outputs:
# 1) a list of matched macisaac sites (the site ID)
# 2) the summary info for each TF
#    # all sites, # matched sites, % matched sites

# arguments


import sys
import string

pvThresh = 100
qvThresh = 100

sys.argv = sys.argv[1:]
while len(sys.argv) > 2:
    next_arg = sys.argv[0]
    sys.argv = sys.argv[1:]
    if next_arg == '-pv-thresh':
        pvThresh = float(sys.argv[0])
        sys.argv = sys.argv[1:]
    elif next_arg == '-qv-thresh':
        qvThresh = float(sys.argv[0])
        sys.argv = sys.argv[1:]
hitFile = sys.argv[0]
siteFile = sys.argv[1]

TFdict = {}

# count the number of sites for each TF
fpSite = open(siteFile, 'r')
for line in fpSite:
    item = line.split()
    TF = item[3].split('_')[0]
    if not(TFdict.has_key(TF)):
        TFdict[TF] = [1, 0]
    else:
        TFdict[TF][0] += 1
fpSite.close()

fpHit = open(hitFile, 'r')
fpHit.readline()
for line in fpHit:
    item = line.split()

    matrixTF = item[0]
    seqID = item[1]
    pv = item[5]
    qv = item[6]

    # count the number of matched sites
    siteTF = seqID.split('_')[0]
    if (siteTF == matrixTF) and (float(pv) <= pvThresh) and (float(qv) <= qvThresh):
        TFdict[matrixTF][1] += 1
        sys.stdout.write(seqID+'\n')
fpHit.close()

sys.stderr.write('TF\t# all sites\t# matched sites\t% matched sites\n')
for t in TFdict.keys():
    sys.stderr.write(t+'\t'+str(TFdict[t][0])+'\t'+
                     str(TFdict[t][1])+'\t'+
                     str(float(TFdict[t][1])/TFdict[t][0])+'\n')
