#!/bin/bash

# parameters
tag=$1
regionType=$2


dataDir=$HOME/proj/yeastDHS/data
srcDir=$HOME/proj/footprintDetector/src
resDir=$HOME/proj/footprintDetector/results

segDir=$resDir/segmenting/$tag/segments
if [ $regionType = 'intergenic' ]
then
    segmentFile=$segDir/segment.intergenic
elif [ $regionType = 'genomic' ]
then 
    segmentFile=$segDir/segment.genomic
fi



flankSize=100
mappableFile=$dataDir/unmappableBases.bed
cutCountsFile=$dataDir/080430.base-count.DS8444.sacCer1.bed

if [ $regionType = 'intergenic' ]
then
    DHSBedFile=$dataDir/sgd.intergenicRegions.noChrM.bed
    mtxDir=$resDir/footprints
    tissue="yeast_intergenic"
elif [ $regionType = 'genomic' ]
then
    DHSBedFile=$dataDir/sgd.genes_intergenicRegions.noChrM.bed
    mtxDir=$HOME/proj/footprintDetector/data
    tissue="sgd.gene_intergenic"
fi

finalDHSBed=$tissue.flanking.bed
cutCountsMtx=$tissue.cutCounts.mtx
mappableMtx=$tissue.mappable.mtx


cd $mtxDir

if [ ! -f $finalDHSBed ]
then
  awk -v fs=$flankSize '{print $1 "\t" $2-fs "\t" $3+fs}' $DHSBedFile > $finalDHSBed
fi

# Compute a matrix. Entries are cutpoint counts 
# each row is a DHS, columns are postions
if [ ! -f $cutCountsMtx ]
then
  $HOME/utilities/extract_genomicSignal_matrix.py \
      -no-region-ids -no-region-scores \
      -varied-width -none-label NaN \
      $finalDHSBed $cutCountsFile \
      > $cutCountsMtx
fi

# Compute a matrix. Entries are binary.
# each row is a DHS, columns are positions 
# "2" means that the position are mappable on BOTH strands.
if [ ! -f $mappableMtx ]
then
  $HOME/utilities/extract_genomicSignal_matrix.py \
      -no-region-ids -no-region-scores \
      -varied-width -none-label 2 \
      $finalDHSBed $mappableFile \
      > $mappableMtx
fi



# rank transformation
transformType=1
# 2-sided
isOneSideBkg=0
# binomial rank
scoringType=1
# bkground size
localBgrWidth=151

if [ $regionType = 'intergenic' ]
then
    outPrefix=segment.intergenic
elif [ $regionType = 'genomic' ]
then 
    outPrefix=segment.genomic
fi

cd $srcDir/matlab
echo "score_segments('$mtxDir/$cutCountsMtx', '$mtxDir/$mappableMtx', '$segmentFile', $localBgrWidth, $flankSize, $transformType, $isOneSideBkg, $scoringType, '$segDir', '$outPrefix')" \
    | /net/gs/vol3/software/matlab-R2008a/bin/matlab -nojvm -nosplash -nodisplay > $segDir/$outPrefix.mat_log



$HOME/proj/tagDHS/src/python/generateBed_footprints.py \
    $mtxDir/$finalDHSBed \
    $segDir/$outPrefix.scores \
    > $segDir/$outPrefix.scores.bed

rm -f $segDir/$outPrefix.scores
rm -f $segDir/$outPrefix.mat_log
